@@ -34,15 +34,15 @@ the code, but the active DOM objects then need to be discarded.
 With the KHTMLAutomation KPart active, the following can be used at a normal
 Python prompt:
 
-  doc = qtxmldom.fromRemoteNode(node)
+  doc = qtxmldom.getRemoteDocument(part)
 
-(Where node has been obtained using the qtxmldom.remote module - see
-examples/remote.py for more information.)
+(Where part has been obtained using the qtxmldom.remote module - see that module
+and examples/remote.py for more information.)
 """
 
 import xml.dom
 
-__version__ = "0.2.5"
+__version__ = "0.2.6"
 
 class Implementation(object):
 
@@ -533,6 +533,12 @@ class Node(object):
     def appendChild(self, node):
         return Node(self._node.appendChild(node._node), self.impl)
 
+    def getElementById(self, value):
+        if hasattr(self._node, "getElementById"):
+            return Node(self._node.getElementById(self.impl.make_string(value)), self.impl)
+        else:
+            return Node(self._node.elementById(self.impl.make_string(value)), self.impl)
+
     def getElementsByTagName(self, tagName):
         if hasattr(self._node, "getElementsByTagName"):
             return NodeList(self._node.getElementsByTagName(self.impl.make_string(tagName)), self.impl)
@@ -783,6 +789,13 @@ class Node(object):
 
 # Convenience functions.
 
+def getRemoteDocument(part):
+
+    "Return the remote document provided by the given 'part'."
+
+    part.wait()
+    return fromRemoteNode(part.getDocument())
+
 def fromRemoteNode(node):
 
     "Return a PyXML-style DOM for the given remote 'node'."
